@@ -188,7 +188,7 @@ enum {
 	BUTTON_PRESS,
 	START_STREAM,
 	STOP_STREAM,
-	TICK,
+	SIGNAL_TICK,
 	LAST_SIGNAL
 };
 
@@ -249,7 +249,7 @@ static void totem_embedded_class_init (TotemEmbeddedClass *klass)
 				g_cclosure_marshal_VOID__VOID,
 				G_TYPE_NONE,
 				0, NULL);
-	signals[TICK] =
+	signals[SIGNAL_TICK] =
 		g_signal_newv ("tick",
 				G_TYPE_FROM_CLASS (object_class),
 				G_SIGNAL_RUN_LAST,
@@ -1205,7 +1205,7 @@ on_about1_activate (GtkButton *button, TotemEmbedded *emb)
 	emb->about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
 				   "name", _("Totem Browser Plugin"),
 				   "version", VERSION,
-				   "copyright", _("Copyright \xc2\xa9 2002-2006 Bastien Nocera"),
+				   "copyright", _("Copyright \xc2\xa9 2002-2007 Bastien Nocera"),
 				   "comments", description,
 				   "authors", authors,
 				   "translator-credits", _("translator-credits"),
@@ -1596,7 +1596,7 @@ on_tick (GtkWidget *bvw,
 			 current_time, stream_length);
 	}
 
-	g_signal_emit (emb, signals[TICK], 0,
+	g_signal_emit (emb, signals[SIGNAL_TICK], 0,
 		       (guint32) current_time, (guint32) stream_length, totem_states[emb->state]);
 }
 
@@ -2074,6 +2074,7 @@ entry_parsed (TotemPlParser *parser,
 {
 	TotemEmbedded *emb = (TotemEmbedded *) data;
 	TotemPlItem *item;
+	int duration;
 
 	if (g_str_has_prefix (uri, "file://") != FALSE
 	    && g_str_has_prefix (emb->base_uri, "file://") == FALSE) {
@@ -2084,9 +2085,14 @@ entry_parsed (TotemPlParser *parser,
 	g_print ("added URI '%s'\n", uri);
 	g_hash_table_foreach (metadata, (GHFunc) entry_metadata_foreach, NULL);
 
+	/* Skip short advert streams */
+	duration = totem_pl_parser_parse_duration (g_hash_table_lookup (metadata, "duration"), FALSE);
+	if (duration == 0)
+		return;
+
 	item = g_new0 (TotemPlItem, 1);
 	item->uri = g_strdup (uri);
-	item->duration = totem_pl_parser_parse_duration (g_hash_table_lookup (metadata, "duration"), FALSE);
+	item->duration = duration;
 	item->starttime = totem_pl_parser_parse_duration (g_hash_table_lookup (metadata, "starttime"), FALSE);
 
 	emb->playlist = g_list_prepend (emb->playlist, item);
