@@ -31,6 +31,7 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include "plparse/totem-disc.h"
+#include "totem-playlist.h"
 
 #define TOTEM_GCONF_PREFIX "/apps/totem"
 
@@ -129,12 +130,15 @@ void	totem_action_seek_time			(Totem *totem, gint64 sec);
 void	totem_action_seek_relative		(Totem *totem, gint64 offset);
 void	totem_action_volume_relative		(Totem *totem, double off_pct);
 gboolean totem_action_set_mrl			(Totem *totem,
-						 const char *mrl);
+						 const char *mrl,
+						 const char *subtitle);
 void	totem_action_set_mrl_and_play		(Totem *totem,
-						 const char *mrl);
+						 const char *mrl, 
+						 const char *subtitle);
 
 gboolean totem_action_set_mrl_with_warning	(Totem *totem,
 						 const char *mrl,
+						 const char *subtitle,
 						 gboolean warn);
 
 void	totem_action_play_media			(Totem *totem,
@@ -161,16 +165,24 @@ gboolean totem_is_seekable			(Totem *totem);
 GtkWindow *totem_get_main_window		(Totem *totem);
 GtkUIManager *totem_get_ui_manager		(Totem *totem);
 GtkWidget *totem_get_video_widget		(Totem *totem);
-char *	totem_get_short_title			(Totem *totem);
 
+/* Current media information */
+char *	totem_get_short_title			(Totem *totem);
 gint64	totem_get_current_time			(Totem *totem);
+
+/* Playlist handling */
 guint	totem_get_playlist_length		(Totem *totem);
 void	totem_action_set_playlist_index		(Totem *totem,
 						 guint index);
 guint	totem_get_playlist_pos			(Totem *totem);
 char *	totem_get_title_at_playlist_pos		(Totem *totem,
 						 guint index);
+void totem_add_to_playlist_and_play		(Totem *totem,
+						 const char *uri,
+						 const char *display_name,
+						 gboolean add_to_recent);
 
+/* Sidebar handling */
 void    totem_add_sidebar_page			(Totem *totem,
 						 const char *page_id,
 						 const char *title,
@@ -178,6 +190,7 @@ void    totem_add_sidebar_page			(Totem *totem,
 void    totem_remove_sidebar_page		(Totem *totem,
 						 const char *page_id);
 
+/* Remote actions */
 void    totem_action_remote			(Totem *totem,
 						 TotemRemoteCommand cmd,
 						 const char *url);
